==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/ScatterSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBase } from "./ScatterBase";
import { markType } from "igniteui-react-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterBaseView } from "./ScatterBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let ScatterSeries = /*@__PURE__*/ (() => {
    class ScatterSeries extends ScatterBase {
        get_dx() {
            return true;
        }
        cg() {
            return new ScatterSeriesView(this);
        }
        iq() {
            return 0.7;
        }
        t4() {
            if (this.t3 == 0) {
                return 2;
            }
            return super.t4();
        }
        o0(a) {
            super.o0(a);
            this.ze = a;
        }
        constructor() {
            super();
            this.ab = ScatterSeries.$;
            this.v0 = new ScatterFrame();
            this.v2 = new ScatterFrame();
            this.vy = new ScatterFrame();
        }
    }
    ScatterSeries.$t = /*@__PURE__*/ markType(ScatterSeries, 'ScatterSeries', ScatterBase.$);
    return ScatterSeries;
})();
/**
 * @hidden
 */
export let ScatterSeriesView = /*@__PURE__*/ (() => {
    class ScatterSeriesView extends ScatterBaseView {
        constructor(a) {
            super(a);
            this.di = null;
            this.di = a;
        }
        au() {
            super.au();
            if (!this.q) {
                this.b4.ua = Defaults.e;
            }
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.s6 = a;
            this.e.ir = 3;
            this.e.is = 2;
            this.e.it = 2;
            this.e.gj = false;
        }
    }
    ScatterSeriesView.$t = /*@__PURE__*/ markType(ScatterSeriesView, 'ScatterSeriesView', ScatterBaseView.$);
    return ScatterSeriesView;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/ScatterSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterBase } from "./ScatterBase";
import { markType } from "igniteui-react-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterBaseView } from "./ScatterBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
export let ScatterSeries = /*@__PURE__*/ (() => {
    class ScatterSeries extends ScatterBase {
        bj() {
            return new ScatterSeries();
        }
        get_eh() {
            return true;
        }
        cr() {
            return new ScatterSeriesView(this);
        }
        jk() {
            return 0.7;
        }
        ww() {
            if (this.wv == 0) {
                return 2;
            }
            return super.ww();
        }
        qz(a) {
            super.qz(a);
            this.aci = a;
        }
        constructor() {
            super();
            this.ab = ScatterSeries.$;
            this.yx = new ScatterFrame();
            this.yz = new ScatterFrame();
            this.yv = new ScatterFrame();
        }
    }
    ScatterSeries.$t = /*@__PURE__*/ markType(ScatterSeries, 'ScatterSeries', ScatterBase.$);
    return ScatterSeries;
})();
/**
 * @hidden
 */
export let ScatterSeriesView = /*@__PURE__*/ (() => {
    class ScatterSeriesView extends ScatterBaseView {
        constructor(a) {
            super(a);
            this.dk = null;
            this.dk = a;
        }
        au() {
            super.au();
            if (!this.q) {
                this.b4.w5 = Defaults.e;
            }
        }
        af() {
            let a = new Color();
            a.colorString = "rgba(95,95,95,0.5)";
            this.e.vx = a;
            this.e.jl = 3;
            this.e.jm = 2;
            this.e.jn = 2;
            this.e.hb = false;
        }
    }
    ScatterSeriesView.$t = /*@__PURE__*/ markType(ScatterSeriesView, 'ScatterSeriesView', ScatterBaseView.$);
    return ScatterSeriesView;
})();
